@@ -2,9 +2,6 @@
  * Defines crate-wide EOP loading functionality
  */
 
-#[cfg(test)]
-use serial_test::serial;
-
 use once_cell::sync::Lazy;
 use std::sync::{Arc, RwLock};
 
@@ -13,6 +10,9 @@ use crate::eop::eop_types::{EOPExtrapolation, EOPType};
 use crate::eop::static_provider::StaticEOPProvider;
 use crate::utils::BraheError;
 
+#[cfg(test)]
+use serial_test::serial;
+
 static GLOBAL_EOP: Lazy<Arc<RwLock<Box<dyn EarthOrientationProvider + Sync + Send>>>> =
     Lazy::new(|| Arc::new(RwLock::new(Box::new(StaticEOPProvider::new()))));
 
@@ -537,6 +537,7 @@ pub fn initialize_eop() -> Result<(), BraheError> {
 }
 
 #[cfg(test)]
+#[cfg_attr(coverage_nightly, coverage(off))]
 #[serial]
 mod tests {
     use super::*;
@@ -546,8 +547,6 @@ mod tests {
     use std::env;
     use std::path::Path;
 
-    use serial_test::serial;
-
     use approx::assert_abs_diff_eq;
 
     fn setup_test_global_eop(eop_interpolation: bool, eop_extrapolation: EOPExtrapolation) {
