@@ -3,15 +3,13 @@
  */
 use nalgebra::Vector3;
 
-use crate::coordinates::{SMatrix3, SVector6};
-#[cfg(test)]
-use serial_test::serial;
+use crate::math::{SMatrix3, SVector6};
 
 use crate::constants;
 use crate::constants::MJD_ZERO;
 use crate::eop;
+use crate::math::matrix3_from_array;
 use crate::time::{Epoch, TimeSystem};
-use crate::utils::matrix3_from_array;
 
 /// Computes the Bias-Precession-Nutation matrix transforming the GCRS to the
 /// CIRS intermediate reference frame. This transformation corrects for the
@@ -269,7 +267,7 @@ pub fn rotation_itrf_to_gcrf(epc: Epoch) -> SMatrix3 {
 /// ```
 /// use brahe::eop::*;
 /// use brahe::constants::R_EARTH;
-/// use brahe::utils::vector3_from_array;
+/// use brahe::vector3_from_array;
 /// use brahe::time::{Epoch, TimeSystem};
 /// use brahe::frames::*;
 ///
@@ -307,7 +305,7 @@ pub fn position_gcrf_to_itrf(epc: Epoch, x: Vector3<f64>) -> Vector3<f64> {
 /// ```
 /// use brahe::eop::*;
 /// use brahe::constants::R_EARTH;
-/// use brahe::utils::vector3_from_array;
+/// use brahe::vector3_from_array;
 /// use brahe::time::{Epoch, TimeSystem};
 /// use brahe::frames::*;
 ///
@@ -344,7 +342,7 @@ pub fn position_itrf_to_gcrf(epc: Epoch, x: Vector3<f64>) -> Vector3<f64> {
 /// # Example
 /// ```
 /// use brahe::eop::*;
-/// use brahe::utils::vector6_from_array;
+/// use brahe::vector6_from_array;
 /// use brahe::constants::R_EARTH;
 /// use brahe::orbits::perigee_velocity;
 /// use brahe::time::{Epoch, TimeSystem};
@@ -398,7 +396,7 @@ pub fn state_gcrf_to_itrf(epc: Epoch, x_gcrf: SVector6) -> SVector6 {
 /// ```
 /// use brahe::eop::*;
 /// use brahe::constants::R_EARTH;
-/// use brahe::utils::vector6_from_array;
+/// use brahe::vector6_from_array;
 /// use brahe::orbits::perigee_velocity;
 /// use brahe::time::{Epoch, TimeSystem};
 /// use brahe::frames::*;
@@ -438,7 +436,7 @@ pub fn state_itrf_to_gcrf(epc: Epoch, x_itrf: SVector6) -> SVector6 {
 }
 
 #[cfg(test)]
-#[serial]
+#[cfg_attr(coverage_nightly, coverage(off))]
 mod tests {
     use approx::assert_abs_diff_eq;
     use nalgebra::Vector3;
@@ -448,9 +446,9 @@ mod tests {
     use crate::coordinates::state_osculating_to_cartesian;
     use crate::eop::{StaticEOPProvider, set_global_eop_provider};
     use crate::frames::*;
+    use crate::math::vector6_from_array;
     use crate::time::{Epoch, TimeSystem};
     use crate::utils::testing::setup_global_test_eop;
-    use crate::utils::vector6_from_array;
 
     #[allow(non_snake_case)]
     #[serial]
@@ -466,6 +464,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_bias_precession_nutation() {
         // Test case reproduction of Example 5.5 from SOFA cookbook
 
@@ -492,6 +491,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_earth_rotation() {
         // Test case reproduction of Example 5.5 from SOFA cookbook
 
@@ -518,6 +518,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_rotation_gcrf_to_itrf() {
         // Test case reproduction of Example 5.5 from SOFA cookbook
         // Testing the explicit GCRF -> ITRF transformation
@@ -545,6 +546,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_rotation_itrf_to_gcrf() {
         // Test case reproduction of Example 5.5 from SOFA cookbook
         // Testing the explicit ITRF -> GCRF transformation
@@ -572,6 +574,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_position_gcrf_to_itrf() {
         setup_global_test_eop();
         let epc = Epoch::from_datetime(2022, 4, 5, 0, 0, 0.0, 0.0, TimeSystem::UTC);
@@ -586,6 +589,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_position_itrf_to_gcrf() {
         setup_global_test_eop();
         let epc = Epoch::from_datetime(2022, 4, 5, 0, 0, 0.0, 0.0, TimeSystem::UTC);
@@ -600,6 +604,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_state_gcrf_to_itrf() {
         setup_global_test_eop();
         let epc = Epoch::from_datetime(2022, 4, 5, 0, 0, 0.0, 0.0, TimeSystem::UTC);
@@ -617,6 +622,7 @@ mod tests {
     }
 
     #[test]
+    #[serial]
     fn test_state_itrf_to_gcrf_circular() {
         setup_global_test_eop();
         let epc = Epoch::from_datetime(2022, 4, 5, 0, 0, 0.0, 0.0, TimeSystem::UTC);
