@@ -2,6 +2,7 @@
 Module implementing orbit dynamics models.
  */
 
+pub use atmospheric_density_models::*;
 pub use drag::*;
 pub use ephemerides::*;
 pub use gravity::*;
@@ -9,6 +10,7 @@ pub use relativity::*;
 pub use solar_radiation_pressure::*;
 pub use third_body::*;
 
+pub mod atmospheric_density_models;
 pub mod drag;
 pub mod ephemerides;
 pub mod gravity;
