@@ -6,14 +6,11 @@ pub use cache::*;
 pub use errors::*;
 pub use formatting::*;
 pub use identifiable::*;
-pub use math::*;
 pub use threading::*;
 
 pub mod cache;
 pub mod errors;
 pub mod formatting;
 pub mod identifiable;
-/// Mathematical utility functions and constants.
-pub mod math;
 pub mod testing;
 pub mod threading;
